### R code from vignette source 'bcpa.rnw'

###################################################
### code chunk number 1: bcpa.rnw:101-102
###################################################
library(bcpa)


###################################################
### code chunk number 2: GetRhoDemo1
###################################################
par(bty="l")
rho <- 0.8
x.full <- arima.sim(1000, model=list(ar = rho))
t.full <- 1:1000
keep <- sort(sample(1:1000, 200))
x <- x.full[keep]
t <- t.full[keep]
plot(t,x, type="l")


###################################################
### code chunk number 3: GetRhoDemo2
###################################################
par(bty="l")
rhos <- seq(0,.99,.01)
L <- rep(NA, length(rhos))
for(i in 1:length(rhos))
  L[i] <- GetL(x,t,rhos[i])
# plot likelihood profile
plot(rhos, L, type="l")
abline(v = rho, lty=2, lwd=2); abline(v = rhos[L == max(L)], lty=3, lwd=2)
legend("bottomleft", legend=c("true value","MLE"), lty=2:3, lwd=2)


###################################################
### code chunk number 4: bcpa.rnw:133-135
###################################################
GetRho(x, t, tau=FALSE)
GetRho(x, t, tau=TRUE)


###################################################
### code chunk number 5: Simp
###################################################
par(bty="l", cex.lab=1.25)
data(Simp)
head(Simp)
plot(Simp)


###################################################
### code chunk number 6: bcpa.rnw:162-164
###################################################
Simp.VT <- GetVT(Simp)
head(Simp.VT)


###################################################
### code chunk number 7: Histograms
###################################################
par(mfrow=c(1,2))
hist(Simp.VT$V, breaks=20, col="grey")
hist(Simp.VT$Theta, breaks=20, col="grey")


###################################################
### code chunk number 8: OneBreak
###################################################
set.seed(2)
par(bty="l")
mu1 <- 5; mu2 <- 3
sigma1 <- 2; sigma2 <- 1
rho1 <- 0.5; rho2 <- 0.5

SimTS <- function(n, mu, rho, sigma)
{
  X.standard <- arima.sim(n, model=list(ar = rho))
  X.standard/sd(X.standard)*sigma + mu
}

# create time series with break at 500
t.full <- 1:1000
t.break <- 500
x.full <- c(SimTS(t.break, mu1, rho1, sigma1), 
            SimTS(max(t.full)-t.break+1, mu2, rho2, sigma2))

# subsample 100 observations and estimate
keep <- sort(sample(1:length(x.full), 100))
x <- x.full[keep]
t <- t.full[keep]
(BB <- GetBestBreak(x,t, tau=FALSE))


###################################################
### code chunk number 9: OneBreak2
###################################################
par(bty="l")
plot(t,x, type="l")
abline(v = 500, col=2, lwd=2, lty=2); abline(v = BB[2], col=2, lwd=2, lty=3)
legend("topright", legend=c("true break", "estimated break"), col=2, lwd=2, lty=2:3)


###################################################
### code chunk number 10: bcpa.rnw:218-219
###################################################
GetModels(x,t,BB[1], tau=FALSE)


###################################################
### code chunk number 11: bcpa.rnw:224-225
###################################################
GetModels(x,t,BB[1], tau=FALSE, K=0.5)


###################################################
### code chunk number 12: bcpa.rnw:229-230
###################################################
GetModels(x,t,BB[1], tau=FALSE, K=5)


###################################################
### code chunk number 13: OneBreak3
###################################################
mu1 <- 0; mu2 <- 0
sigma1 <- 1; sigma2 <- 1
rho1 <- 0.9; rho2 <- 0.2
set.seed(11)
SimTS <- function(n, mu, rho, sigma)
{
  X.standard <- arima.sim(n, model=list(ar = rho))
  X.standard/sd(X.standard)*sigma + mu
}

# create time series with break at 500
t.full <- 1:1000
t.break <- 500
x.full <- c(SimTS(t.break, mu1, rho1, sigma1), SimTS(max(t.full)-t.break+1, mu2, rho2, sigma2))

# subsample 100 observations and estimate
keep <- sort(sample(1:length(x.full), 100))
x <- x.full[keep]
t <- t.full[keep]
BB <- GetBestBreak(x,t, tau=FALSE)

par(bty="l")
plot(t,x, type="l")

abline(v = 500, col=2, lwd=2, lty=2)
abline(v = BB[2], col=2, lwd=2, lty=3)
legend("topright", legend=c("true break", "estimated break"), col=2, lwd=2, lty=2:3)


###################################################
### code chunk number 14: bcpa.rnw:267-268
###################################################
GetModels(x,t,BB[1], tau=FALSE)


###################################################
### code chunk number 15: LampreyBCPA
###################################################
  Simp.ws <- WindowSweep(Simp.VT, "V*cos(Theta)", windowsize=50, progress=FALSE, K=2)


###################################################
### code chunk number 16: bcpa.rnw:283-284
###################################################
head(Simp.ws$ws) 


###################################################
### code chunk number 17: BCPAsmooth
###################################################
par(mfrow=c(2,1), mar=c(0,4,0,1), oma=c(4,0,1,0), bty="l")
plot(Simp.ws, type="smooth")
plot(Simp.ws, type="smooth", threshold = 7)


###################################################
### code chunk number 18: BCPAflat
###################################################
par(mfrow=c(2,1), mar=c(0,4,0,1), oma=c(4,0,1,0), bty="l")
plot(Simp.ws, type="flat")
plot(Simp.ws, type="flat", clusterwidth=3)


###################################################
### code chunk number 19: bcpa.rnw:309-310
###################################################
ChangePointSummary(Simp.ws, clusterwidth=3)


###################################################
### code chunk number 20: BCPApaths
###################################################
par(mfrow=c(1,2))
PathPlot(Simp, Simp.ws, type="flat", clusterwidth = 3, main="Flat BCPA")
PathPlot(Simp, Simp.ws, type="smooth", main="Smooth BCPA")


###################################################
### code chunk number 21: bcpa.rnw:326-328
###################################################
par(bty="l")
PhasePlot(Simp.ws, type="smooth", clusterwidth = 3)


###################################################
### code chunk number 22: DiagnosticPlot
###################################################
par(bty="l")
DiagPlot(Simp.ws)


